Skip to contents

Plots the two input series over the sample, with the test statistic and the lag in the title.

Usage

# S3 method for class 'cobubble_test_obj'
autoplot(object, ...)

Arguments

object

An object of class cobubble_test, the output of cobubble_test.

...

Further arguments passed to methods. Not used.

Value

A ggplot

See also