Skip to contents

Plots the CUSUM detector path against its boundary, with one panel for each series and vertical markers at the end of the training sample and at the alarm date.

Usage

# S3 method for class 'monitor_cusum_obj'
autoplot(object, ...)

Arguments

object

An object of class monitor_cusum_obj, the output of monitor_cusum.

...

Further arguments passed to methods. Not used.

Value

A ggplot

See also