Skip to contents

Plots the monitoring statistic against its boundary, with one panel for each series and vertical markers at the end of the training sample and at the alarm date.

Usage

# S3 method for class 'monitor_obj'
autoplot(object, ...)

Arguments

object

An object of class monitor_obj, the output of monitor.

...

Further arguments passed to methods. Not used.

Value

A ggplot

See also