psy_minw and psy_ds use the rules-of- thumb proposed by
Phillips et al. (2015) to compute the minimum window size and the
minimum duration of an episode of exuberance, respectively.
Value
psy_minw: a single integer, the minimum window length.
psy_ds: a single integer, the minimum episode duration in
observations.
Details
For the minimum duration period, psy_ds allows the user to choose from two rules:
$$\text{rule}_1 = \delta \log(n) \quad \text{and} \quad \text{rule}_2 = \delta \log(n)/n$$
delta depends on the frequency of the data and the minimal duration condition.
References
Phillips, P. C. B., Shi, S., & Yu, J. (2015). Testing for Multiple Bubbles: Historical Episodes of Exuberance and Collapse in the S&P 500. International Economic Review, 56(4), 1043-1078. doi:10.1111/iere.12132