R/radf_sbz.R
autoplot.radf_sbz_union_obj.Rd
Plots the supDF, supBZ and union statistics of each series against their bootstrap critical values at the chosen significance level.
# S3 method for class 'radf_sbz_union_obj' autoplot(object, sig_lvl = 95, ...)
A radf_sbz_union object.
radf_sbz_union
Significance level at which to plot the critical value, one of 90, 95 (default) or 99.
90
95
99
Further arguments passed to methods. Not used.
A ggplot