Estimate the Explosive Autoregressive Root over a Sub-Sample
Source:R/explosive_root.R
explosive_root.RdFits the no-intercept AR(1) regression \(y_t = \rho y_{t-1} + \epsilon_t\)
over the sub-sample from:to of data – the model used by
Phillips & Magdalinos (2007) and Guo, Sun & Wang (2019) for inference on a
(moderately) explosive root, e.g. an episode already identified by
datestamp. No intercept is included, following Phillips &
Magdalinos's model (their eq. 58 excludes it "to exclude the presence of
a deterministically explosive component").
Arguments
- data
A numeric vector (a single series).
- from, to
Integer row positions delimiting the sub-sample (e.g. from
datestamp()'sStart/End, converted to row positions if they are dates:match(start_date, index(x))).
References
Phillips, P. C. B., & Magdalinos, T. (2007). Limit theory for moderate deviations from a unit root. Journal of Econometrics, 136(1), 115-130.
Guo, G., Sun, Y., & Wang, S. (2019). Testing for moderate explosiveness. The Econometrics Journal, 22(3), 279-303.
See also
root_ci for a confidence interval and doubling
time based on this estimate.