scale_exuber_manual allows specifying the color, size and linetype in
autoplot.radf_obj mappings. theme_exuber is a complete theme which control
all non-data display.
Arguments
- color_values
a set of color values to map data values to.
- linetype_values
a set of linetype values to map data values to.
- size_values
a set of size values to map data values to.
- base_size
base font size, given in pts.
- base_family
base font family
- base_line_size
base size for line elements
- base_rect_size
base size for rect elements