Tidy or augment and then join objects of class radf_obj and radf_cv. The
object of reference is the radf_cv. For example, if panel critical values
are provided the function will return the panel test statistic.
Usage
# S3 method for class 'radf_obj'
tidy_join(x, y = NULL, ...)
# S3 method for class 'radf_obj'
augment_join(x, y = NULL, trunc = TRUE, ...)